@@ -81,7 +81,7 @@ def generate_inputs(
     overwrite: bool = False,
 ) -> str:
     """
-    Generates input file for the :class:`FASTOADProblem` specified in configuration_file_path.
+    Generates input file for the problem specified in configuration_file_path.
 
     :param configuration_file_path: where the path of input file to write is set
     :param source_path: path of file data will be taken from
@@ -118,7 +118,7 @@ def list_variables(
     tablefmt: str = "grid",
 ):
     """
-    Writes list of variables for the :class:`FASTOADProblem` specified in configuration_file_path.
+    Writes list of variables for the problem specified in configuration_file_path.
 
     List is generally written as text. It can be displayed as a scrollable table view if:
     - function is used in an interactive IPython shell
@@ -226,7 +226,6 @@ def list_modules(
     if configuration_file_path:
         conf = FASTOADProblemConfigurator(configuration_file_path)
         conf._set_configuration_modifier(_PROBLEM_CONFIGURATOR)
-        conf.load(configuration_file_path)
     # As the problem has been configured, BundleLoader now knows additional registered systems
 
     if verbose:
@@ -520,7 +519,7 @@ def variable_viewer(file_path: str, file_formatter: IVariableIOFormatter = None,
 
         handle = viewer.display()
     else:
-        variables = DataFile(file_path, file_formatter)
+        variables = DataFile(file_path, formatter=file_formatter)
         variables.sort(key=lambda var: var.name)
 
         table = variables.to_dataframe()[["name", "value", "units", "is_input", "desc"]].rename(
