@@ -72,7 +72,7 @@ class Variable(Hashable):
     `here <http://openmdao.org/twodocs/versions/latest/_srcdocs/packages/core/
     component.html#openmdao.core.component.Component.add_output>`_.
 
-    These keys can be listed with class method :meth:`get_authorized_keys`.
+    These keys can be listed with class method :meth:`get_openmdao_keys`.
     **Any other key in kwargs will be silently ignored.**
 
     Special behaviour: :meth:`description` will return the content of kwargs['desc']
@@ -386,7 +386,7 @@ class VariableList(list):
         """
         Creates a DataFrame instance from a VariableList instance.
 
-        Column names are "name" + the keys returned by :meth:`Variable.get_authorized_keys`.
+        Column names are "name" + the keys returned by :meth:`Variable.get_openmdao_keys`.
         Values in Series "value" are floats or lists (numpy arrays are converted).
 
         :return: a pandas DataFrame instance with all variables from current list
@@ -474,7 +474,7 @@ class VariableList(list):
         Creates a VariableList instance from a pandas DataFrame instance.
 
         The DataFrame instance is expected to have column names "name" + some keys among the ones given by
-        :meth:`Variable.get_authorized_keys`.
+        :meth:`Variable.get_openmdao_keys`.
 
         :param df: a DataFrame instance
         :return: a VariableList instance
@@ -576,6 +576,16 @@ class VariableList(list):
                 if "." not in metadata["prom_name"]
             }
 
+            if get_promoted_names:
+                # Check connections
+                for name, metadata in inputs.copy().items():
+                    source_name = problem.model.get_source(name)
+                    if not source_name.startswith("_auto_ivc.") and source_name != name:
+                        # This variable is connected to another variable of the problem: it is
+                        # not an actual problem input. Let's move it to outputs.
+                        del inputs[name]
+                        outputs[name] = metadata
+
         # Add "is_input" field
         for metadata in inputs.values():
             metadata["is_input"] = True
@@ -587,6 +597,13 @@ class VariableList(list):
             final_inputs = inputs
             final_outputs = outputs
         else:
+            # Remove from inputs the variables that are outputs of some other component
+            promoted_inputs = {
+                metadata["prom_name"]: dict(metadata, is_input=True)
+                for metadata in inputs.values()
+                # if metadata["prom_name"] not in promoted_outputs
+            }
+
             promoted_outputs = {}
             for metadata in outputs.values():
                 prom_name = metadata["prom_name"]
@@ -618,15 +635,8 @@ class VariableList(list):
                         # We already have a non-NaN value and current variable provides no unit.
                         # No need for using the current variable.
                         continue
-
-                promoted_outputs[prom_name] = metadata
-
-            # Remove from inputs the variables that are outputs of some other component
-            promoted_inputs = {
-                metadata["prom_name"]: dict(metadata, is_input=True)
-                for metadata in inputs.values()
-                if metadata["prom_name"] not in promoted_outputs
-            }
+                if prom_name not in promoted_inputs:
+                    promoted_outputs[prom_name] = metadata
 
             final_inputs = promoted_inputs
             final_outputs = promoted_outputs
